% Programme de trace des XBT de la campagne PIRATA-FR18
%

clear all; close all; clc

% Tailles des marques
% -------------------
markersize_XBT       = 5;
markersize_MOUILLAGE = 7;
markersize_VILLE     = 6;

% Nom pour le fichier d'impression
% --------------------------------
fileName = 'PIRATA-FR18-CruiseTrack-XBT';

% Fichier contenant le trajet de la campagne XBT
% --------------------------------------------------------------
FileStaPos = 'pirata-fr18.xbt';
TitlePlot = 'PIRATA-FR18 cruise - XBT';

% Fichier contenant le trajet de la campagne TSG
% --------------------------------------------------------------
FileTsgPos = '../THERMO/pirata-fr18_tsg';

% Zone geographique
% Pour tracer une carte qui chevauche le meridien 180, il
% faut exprimer les longitudes de 0 a 360. Ceci impose de
% transformer les longitudes lors de la lecture des donnees
% ---------------------------------------------------------
latmin = -15; latmax = 10; latint = 5;
lonmin = -15; lonmax = 15; lonint = 5;

% Contours de bathymtrie
% -----------------------
niveaux = [-3000 -1000 -200];

% Projection cartographique
% -------------------------
F = figure;
m_proj('mercator','lat',[latmin latmax],'long',[lonmin lonmax]);

% Contour de cote detaille
% ------------------------
 m_gshhs_i('patch',[.7 .7 .7]);

% Contour de cote moins detaille
% ------------------------------
%m_gshhs_l('patch',[.7 .7 .7]);

% Bathymetrie 5'x5'
% -----------------
[cs,h] = m_tbase('contour',niveaux);
% m_tbase('contourf',[ -4000 -3000 -2000 -200], 'edgecolor','k');

% Trace de la grille
% ------------------
m_grid('box','fancy','tickdir','in', 'ytick', [-5:latint:15], ...
  'xtick', [lonmin:lonint:lonmax], 'Fontsize', [10]);

% Ajoute un titre
% ---------------
title( TitlePlot, 'Fontsize', 12, 'FontWeight', 'bold' );


% Lecture et stockage de la feuille des profils XBT
% -------------------------------------------------
[st,date,heure,lat,lats,lon,lons,depth,type,t] = ...
   textread(FileStaPos,'%d %s %s %s %s %s %s %d %s %s','headerlines',2);
   

% Conversion lat et lon en degre decimaux
% -------------------------------------------
lat = char(lat);
lat = HMtoH(str2num(lat(:,(1:2))) +  str2num(lat(:,(4:8))) /100);
ind =find(char(lats) == 'S');
for i=1:size(ind)
  lat(ind(i)) = lat(ind(i)) * -1;
end  
lon = char(lon);
lon = HMtoH(str2num(lon(:,(1:3))) +  str2num(lon(:,(5:9))) /100);
ind =find(char(lons) == 'W');
for i=1:size(ind)
  lon(ind(i)) = lon(ind(i)) * -1;
end 

% Lecture et stockage de la route depuis les donnees TSG
% ------------------------------------------------------
[year,dayd,latx,lonx,ssjt,ssps,cndc,sstp] = ...
    textread(FileTsgPos,'%f %f %f %f %f %f %f %f','headerlines',2);

% Trace du trajet
% ---------------
m_plot(lonx,latx,'LineWidth',2);

% affichage Cotonou
% -----------------
%m_line( -52.135, 4.61,'LineStyle', 'none','marker','o',...
m_line( HMtoH(2.27), HMtoH(6.2), 'LineStyle', 'none','marker','o',...
    'markersize',markersize_VILLE,'color','k','markerfacecolor','k');
m_text( 0, 7.5,'Cotonou','vertical','middle', 'Fontsize', [12]);

% Trace de la position des stations XBT
% --------------------------------------------------

% Couleur rouge pour XCTD, vert pour XBT
ind = strncmp(type,'XCTD',4);
for i=1:length(ind)
  if ind(i) == 0
    m_line( lon(i), lat(i),'marker','o','markersize',4,'color','k','markerfacecolor','g');
  end  
end
for i=1:length(ind)
  if ind(i)
    m_line( lon(i), lat(i),'marker','o','markersize',4,'color','k','markerfacecolor','r');
  end  
end

% trac en X (long) Y (lat)
m_line( -2.5, -10,'LineStyle', 'none','marker','o','markersize',5,'color','k','markerfacecolor','g');
m_text( -2, -10,'Profils XBT   800 m','vertical','middle', 'Fontsize', [12]);
% m_line( -2.5, -12,'LineStyle', 'none','marker','o','markersize',5,'color','k','markerfacecolor','r');
% m_text( -2, -12,'Profils XCTD 1100 m','vertical','middle', 'Fontsize', [12]);

% impression
% ----------
cmd = ['print -f' ,num2str(F), ' -d', 'png', ' ', fileName];
eval(cmd);
cmd = ['print -f' ,num2str(F), ' -d', 'jpeg', ' ', fileName];
eval(cmd);



