#!/usr/bin/perl -w
#
# solex-fr18.pl  PIRATA-FR18  J Grelet IRD septembre 2008
# $Id$
# analyse des fichiers archives par Solex sur l'Antea campagne PIRATA-FR18 
# du 02/09/2008 du 05/10/2008
#
# usage perl solex-fr18.pl   
#

use strict;
use Time::Local;
use Date::Manip;
use File::Basename;
use Getopt::Long;

#------------------------------------------------------------------------------
# Les variables globales
#------------------------------------------------------------------------------
our $VERSION = '1.0';
our $AUTHOR  = 'jgrelet IRD sept 2007';
my  $DEBUG   = 0;
my  $ECHO;

# a mettre sous forme d'argument ligne de commande
my  $CYCLE_MESURE   = "PIRATA-FR18";
my  $SHIP           = "ANTEA";
my  $INSTITUTE      = "IRD";
my  $PI             = "BOURLES";
my  $INSTRUMENT_MTO = "BATOS";
my  $INSTRUMENT_TSG = "SBE21";
my  $INSTRUMENT_SN  = "";   # a lire dans le fichier
my  $CONTEXTE       = "AMMA";
my  $TIMEZONE       = "GMT";
my  $FORMAT_DATE    = "DMY";
my  $CODE           = "1A";
my  $date_debut     = "02/09/2008";
my  $date_fin       = "05/10/2008";

my  $softwareMeteo  = "BATOS";
my  $softwareMeteoVersion = "";
my  $softwareTsg    = undef; 
my  $softwareTsgVersion = "";

my  $version;
my  $help;
my  $xml           = 1;
my  $ascii         = undef;
my  $dtd           = undef;

# handles de fichiers
my ($mtoHdl,$mtodHdl,$logHdl);

my ($year,$julien,$time,$tr);
my ($lat_deg,$lat_min,$lat_dec);
my ($long_deg,$long_min,$long_dec);
my ($lat_gga_s,$long_gga_s,$gpsTime,$gpsQual);
my $lat_gga = '';
my $long_gga = '';
# capteurs
my ($jmet,$jsbe);
my ($date,$dateSolex,$heure,$code,$lat,$long,$sonde,$tair,$tmer,$hum);
my ($patm,$rad,$rosee,$dir,$vit,$cond,$sbe38,$sss,$sst_cuve,$unit);
my $ecart;
# trames
my $GGA            = undef;
my $status         = 0;

#------------------------------------------------------------------------------
# version()
#------------------------------------------------------------------------------	
sub version() {
  print "Version: $VERSION\nAuthor: $AUTHOR\n\n";	
  exit 1;
}

#------------------------------------------------------------------------------
# usage()
#------------------------------------------------------------------------------	
sub usage() {
  print STDERR "\nusage: perl solex-fr18.pl [options]  <files>\n\n";
  print STDERR   "Options:\n    --help                 Display this help message\n";
  print STDERR   "    --version              program version\n";
  print STDERR   "    --debug=[1-3]          debug info\n";
  print STDERR   "    --echo                 display filenames processed\n";
  print STDERR   "    --ascii                ASCII output instead XML\n";
  print STDERR   "    --xml                  XML output (default)\n";
  print STDERR   "    --local                use local DTD\n";
  print STDERR   "\naccept short options like -d1 -t2\n\n";
  print STDERR   "Solex processing example:\n-------------------------\n\$ perl solex-fr18.pl --echo --local\n\n"; 
  exit;
}


#------------------------------------------------------------------------------
# get_options()
# analyse les options
#------------------------------------------------------------------------------	
sub get_options() {
  
  &GetOptions ("ascii"           => \$ascii, 
               "xml"             => \$xml,  
               "debug=i"         => \$DEBUG,  
               "echo"            => \$ECHO,  
               "local"           => \$dtd,  
	             "version"         => \$version,  
               "help"            => \$help)  or &usage;  
       
  &version if $version;	
  &usage   if $help;	
  $xml = undef if $ascii;   
}

#------------------------------------------------------------------------------
# fonctions de calcul de la position/date
#------------------------------------------------------------------------------
sub position {
  my($deg,$min,$hemi)=@_;
  my $sign = 1;
  if( $hemi eq "S" || $hemi eq "W") {
    $sign = -1;
  }
  return( ( $deg + ( $min / 60 ) ) * $sign ); 
}

sub julian {
  my($jj,$h,$m,$s)=@_;
  #print "$jj $h $m $s\n";
  my $tmp = ( ($h * 3600) + ( $m * 60 ) +$s ) / (1440 * 60);
  return( $jj + $tmp ); 
}

#------------------------------------------------------------------------------
# entete XML
#------------------------------------------------------------------------------
sub entete_xml { 
  my($handle,$software,$softVersion,$instrumentType,$INSTRUMENT_SN) = @_;
  my $today = &UnixDate( &ParseDate("today"), "%d/%m/%Y");

  print $handle '<?xml version="1.0" encoding="ISO-8859-1"?>' . "\n"; 
  # les commentaires ne sont pas accept�s par XML Toolbox Matlab de Geodise
    if ( defined $dtd ) {
    print  $handle '<!DOCTYPE OCEANO SYSTEM "M:\ACQUISIT\oceano.dtd">' . "\n";
    #print  $handle '<!DOCTYPE OCEANO PUBLIC "-//US191//DTD OCEANO//FR" "http://antea/acquisit/oceano.dtd">' . "\n";
  } else {  
    print $handle '<!DOCTYPE OCEANO PUBLIC "-//US191//DTD OCEANO//FR" "http://www.brest.ird.fr/us191/database/oceano.dtd">' . "\n";
  }
  print  $handle '<OCEANO TYPE="TRAJECTOIRE">' . "\n";
  print  $handle "  <ENTETE>\n";
  print  $handle "    <PLATEFORME>\n";
  print  $handle "      <LIBELLE>$SHIP</LIBELLE>\n";  
  print  $handle "    </PLATEFORME>\n";
  print  $handle "    <CYCLE_MESURE CONTEXTE=\"$CONTEXTE\" TIMEZONE=\"$TIMEZONE\" FORMAT=\"$FORMAT_DATE\">\n";  
  print  $handle "      <LIBELLE>$CYCLE_MESURE</LIBELLE>\n";  
  print  $handle "      <INSTITUT>$INSTITUTE</INSTITUT>\n";  
  print  $handle "      <RESPONSABLE>$PI</RESPONSABLE>\n"; 
  print  $handle "      <ACQUISITION LOGICIEL=\"$software\" VERSION=\"$softVersion\"></ACQUISITION>\n"; 
  print  $handle "      <TRAITEMENT LOGICIEL=\"$0\" VERSION=\"$VERSION\"></TRAITEMENT>\n"; 
  print  $handle "      <VALIDATION LOGICIEL=\"datagui\" VERSION=\"1.0\" DATE=\"$today\" OPERATEUR=\"$PI\" CODIFICATION=\"OOPC\">\n";
  print  $handle "        <CODE>$CODE</CODE>\n";	    
  print  $handle "        <COMMENTAIRE>Extraction r�alis�e depuis les sorties brutes SOLEX</COMMENTAIRE>\n";
  print  $handle "      </VALIDATION>\n";  
  print  $handle "    </CYCLE_MESURE>\n";  
  print  $handle "    <INSTRUMENT TYPE=\"$INSTRUMENT_MTO\" NUMERO_SERIE=\"$INSTRUMENT_SN\">\n"; 
  print  $handle "    </INSTRUMENT>\n";  
  print  $handle "  </ENTETE>\n";  
  print  $handle "  <DATA>\n";  
}

#------------------------------------------------------------------------------
# Debut du programme principal
#------------------------------------------------------------------------------
&Date_Init( "TZ=UTC" );
&usage if( $#ARGV == -1);
&get_options;

# initialisation des valeurs de capteurs
$sonde = $tair = $tmer = $hum = $patm = $rad = $rosee = $dir = $vit = 1e+36;

# ouverture des fichiers
my $mto_file = lc $CYCLE_MESURE.'_mto';     # meteo decimal
$mto_file .= '.xml' if defined $xml;        # en xml
my $mto_hdr_file = lc $CYCLE_MESURE.'.mto'; # meteo DMS
my $mto_log_file = lc $CYCLE_MESURE.'.log'; # meteo log

open( $mtoHdl,  "+> $mto_hdr_file" ) or die "Can't open file : $mto_hdr_file\n";
open( $mtodHdl, "+> $mto_file" )     or die "Can't open file : $mto_file\n";
open( $logHdl,  "+> $mto_log_file" ) or die "Can't open file : $mto_log_file\n";

# ecriture des entetes
if ( defined $xml ) {
  &entete_xml($mtodHdl,$softwareMeteo, $softwareMeteoVersion, $INSTRUMENT_MTO, "");
  print $mtodHdl "YEAR    DAYD       LATX        LONX     SSTP  DRYT  WMSP  WDIR   ATMS  RELH\n"; 
} 
else {
  print $mtodHdl  "$CYCLE_MESURE  $SHIP  $INSTITUTE  $INSTRUMENT_MTO\n";
  print $mtodHdl "YEAR    DAYD       LATX        LONX     SSTP  DRYT  WMSP  WDIR   ATMS  RELH\n"; 
}

# dans tous les cas, on cree l'entete des fichiers au format non decimal
print $mtoHdl  "$CYCLE_MESURE  $SHIP  $INSTITUTE  $INSTRUMENT_MTO\n";
print $mtoHdl  "   Date      Time     Latitude       Longitude     SSTP  DRYT  WMSP  WDIR   ATMS  RELH\n"; 

# boucle de lecture sur les fichiers
while( <DATA> ){
  print STDERR "Lit : $_" if defined $ECHO;
  if( not open( FILE, $_ )) {
	  warn("Erreur: $!");
          print $logHdl "Erreur: $!\n"; 
	  next FILE;
  }
  print $logHdl "\nLit: $_"; 
LINE: 
  while( <FILE> ){           # lit le fichier
    next LINE if $. < 4;     # saute les 3 premieres lignes d'entete
    #print "Ligne: $_\n";
    # chomp ne marche pas correctement car le fichier .con est au format DOS
    # avec un CRLF (^M^J ou OD OA) a la fin de chaque ligne
    # on vire le CR si present en fin de ligne
    $_ =~ s/^(.+)\r$/$1/;

    # cas de la trame GGA
    if ( /\$INGGA/ ) {
      $GGA = $_;  # memorise la trame en cas d'erreur
      # decodage de la trame GGA
      if ( /^(\d*):\d*,\$INGGA,(\d*\.\d*),(\d*\.\d*),(\w{1}),(\d*\.\d*),(\w{1}),\d{1}/ ) {
        ($dateSolex,$gpsTime,$lat_gga,$lat_gga_s,$long_gga,$long_gga_s,
		$gpsQual) = ($1,$2,$3,$4,$5,$6,$7);
      }	  
    }
    # decodage de la trame MTW Tmer 
    if ( /^(\d*):\d*,\$WIMTW,(\d*\.\d*),C/ ) {
      ($dateSolex,$tmer) = ($1,$2);
    }
    # decodage de la trame XDR Patm 
    if ( /^(\d*):\d*,\$WIXDR,P,(\d*\.\d*),B,P/ ) {
      ($dateSolex,$patm) = ($1,$2*1000);    # passe de 1.0156 => 1015.6
    }                                   # attention Batos ne delivre pas decimal
    # decodage de la trame XDR Tair 
    if ( /^(\d*):\d*,\$WIXDR,C,(\d*\.\d*),C,TA/ ) {
      ($dateSolex,$tair) = ($1,$2);
    }
    # decodage de la trame XDR Humidite
    if ( /^(\d*):\d*,\$WIXDR,H,(\d*),P,UU/ ) {
      ($dateSolex,$hum) = ($1,$2);
    }
    # decodage de la trame MHW vent vrai CINNA
    if ( /^(\d*):\d*,\$INMWV,(\d*\.\d*),T,(\d*\.\d*),(\w{1}),A/ ) {
      ($dateSolex,$dir,$vit,$unit) = ($1,$2,$3,$4);
      if ($unit eq 'N') {$vit = $vit / 1.852;}
    } 
    # decodage de la trame MHW vent vrai batos 
    # T: true R: relative N:noeuds;K:km/h;M:m/s
    if ( /^(\d*):\d*,\$WIMWV,(\d*),T,(\d*),\w,A/ ) {
      # on ne decode pas, sert de declencheur uniquement, utilise INMWV	    
      # ($dateSolex,$dir,$vit) = ($1,$2,$3);
      # Valid date formats include the ISO 8601 formats: YYYYMMDDHHMNSS
      $time = &ParseDateString('20'.$dateSolex);
      # transforme le day_of_year en julian day 0
      $julien = &julian( &UnixDate($time,"%j"),
                         &UnixDate($time,"%H"),&UnixDate($time,"%M"),
	                 &UnixDate($time,"%S") ) - 1;
      $year   = &UnixDate($time,"%Y");	
      if ( $lat_gga =~ /(\d{2})(\d{2}\.\d*)/ ) {
        ($lat_deg,$lat_min) = ($1,$2);
        $lat_dec  = &position($lat_deg,$lat_min,$lat_gga_s);
	$status = 1;      
      } else {
	$status = 0;      
        next LINE; 
      }
      if ( $long_gga =~ /(\d{3})(\d{2}\.\d*)/ ) {
        ($long_deg,$long_min) = ($1,$2);
        $long_dec = &position($long_deg,$long_min,$long_gga_s);
	$status = 1;      
      } else {
	$status = 0;      
        next LINE; 
      }
      if ( $status && defined $GGA ) {
	#printf STDERR 
	printf $mtodHdl 
          "%4d %10.9g %+010.6f %+011.6f %5.4g %5.4g %5.3g %5.3g %6.5g %5.3g\n",
           $year,$julien,$lat_dec,$long_dec,
           $tmer,$tair,$vit,$dir,$patm,$hum;
        #printf STDERR 
        printf $mtoHdl 
          "%s %02d%08.5f %s  %03d%08.5f %s %5.4g %5.4g %5.3g %5.3g %6.5g %5.3g\n",
           &UnixDate($time,"%d/%m/%Y %H:%M:%S"),
           $lat_deg,$lat_min,$lat_gga_s,$long_deg,$long_min,$long_gga_s,
           $tmer,$tair,$vit,$dir,$patm,$hum;
        # initialisation des valeurs de capteurs
        $tair = $tmer = $hum = $patm = $rad = $rosee = $dir = $vit = 1e+36;
	$lat_gga = $long_gga = '';
      }	else {
        print $logHdl "\nErreur: $dateSolex"; 
      }	      
      $GGA = undef;
    }
  }
  $. = 0;
}  
if( defined $xml ) {
  print  $mtodHdl "  </DATA>\n</OCEANO>\n";  
}  
close $mtodHdl;
close $mtoHdl;
close $logHdl;

# $ ls -1 data/*.log
__DATA__
data/080902074613.log
data/080903070436.log
data/080904071949.log
data/080904195516.log
data/080909095226.log
data/080909110521.log
data/080909125949.log
data/080910064102.log
data/080911072643.log
data/080912073302.log
data/080913071636.log
data/080914062924.log
data/080915141957.log
data/080916065932.log
data/080918083335.log
data/080919125029.log
data/080920080655.log
data/080921071753.log
data/080922105115.log
data/080923072329.log
data/080926095838.log
data/080927080256.log
data/080927135843.log
data/080928075741.log
data/080929074151.log
data/080930080855.log
data/081001101942.log
data/081002093916.log
data/081003084713.log
data/081004083533.log
data/081005082431.log
