#!/usr/bin/perl -w
#
# extraction des temperature/salinite TSG mesuree a  3.5 m avec analyses 
# Salinometre
#
# J Grelet IRD fevrier 2004 - sept 2008
# 
# $Id$ 

use strict; # necessite de declarer toutes les variables globales
#use diagnostics;

use Time::Local;
use Date::Manip;
use File::Basename;
use Data::Dumper;
use Getopt::Long;
use Switch;
use seawater;

#------------------------------------------------------------------------------
# Les variables globales
#------------------------------------------------------------------------------
our $VERSION = '1.0';
our $AUTHOR  = 'jgrelet IRD sep 2008';
my  $DEBUG   = 0;
my  $ECHO;

# a mettre sous forme d'argument ligne de commande
my  $CONTEXTE = "AMMA";
my  $TIMEZONE = "GMT";
my  $FORMAT_DATE = "DMY";
my  $CODE = "1A";
my  $date_debut = "02/09/2008";
my  $date_fin   = "05/10/2008";
my  $tsgFile = "../THERMO/pirata-fr18.tsg";
my  $anaFile = "./pirata-fr18-ana-tsg.txt";
my  $outFile = "./pirata-fr18-salino-tsg.txt";

my  $version;
my  $help;
my  $xml   = undef;
my  $ascii = 1;

my $code     = -1;  # code pour l'entete

my $hdr_file;
my $hdr_file_dec;
my $institute;
my $ctdType;
my $inst_sn;
my $pi;

my $cycle_mesure = "PIRATA-FR18";
my $ship         = "ANTEA";
my($seasave_version) = undef;
my($sample,$latitude,$longitude,$Temp_XBT,$SSJT,$SSTP,$ANA_PSAL,$SSPS);
my($year,$lat, $lat_dec, $lat_deg, $lat_min, $lat_hemi);
my($long, $long_dec, $long_deg, $long_min, $long_hemi);
my($julien, $h_date, $date, $mois, $jour, $annee, $heure, $min, $time);
my($dateTSG,$heureTSG,$flag);

#------------------------------------------------------------------------------
# version()
#------------------------------------------------------------------------------	
sub version() {
  print "Version: $VERSION\nAuthor: $AUTHOR\n\n";	
  exit 1;
}	

#------------------------------------------------------------------------------
# usage()
#------------------------------------------------------------------------------	
sub usage() {
  print STDERR "\nusage: salino-tsg-fr18.pl [options] <files>\n\n";
  print STDERR   "Options:\n    --help                 Display this help message\n";
  print STDERR   "    --version              program version\n";
  print STDERR   "    --echo                 display filenames processed\n";
  print STDERR   "    --cycle_mesure=<name>  cycle_mesure name\n";
  print STDERR   "    --ship=<ship_name>     ship name\n";
  print STDERR   "\naccept short options like -d1 -t2\n\n";
  print STDERR   "example:\n\$ perl salino-tsg-fr18.pl --echo\n"; 
  exit 1;
}

#------------------------------------------------------------------------------
# get_options()
# analyse les options
#------------------------------------------------------------------------------	
sub get_options() {
  
  &GetOptions ("cycle_mesure=s"  => \$cycle_mesure,    
               "ship=s"          => \$ship,  
               "echo"            => \$ECHO,  	       
               "version"         => \$version,  
               "help"            => \$help)  or &usage;  
       
  &version if $version;	
  &usage   if $help;
  $xml = undef if $ascii;    
}

#------------------------------------------------------------------------------
# fonctions de calcul de la position/date
#------------------------------------------------------------------------------
sub position {
  my($deg,$min,$hemi) = @_;
  my $sign = 1;
  if( $hemi eq "S" || $hemi eq "W") {
    $sign = -1;
  }
  my $tmp = $min;
  $min = abs $tmp;
  my $sec = ($tmp - $min ) * 100;
  return( ( $deg + ( $min + $sec / 100 ) / 60 ) * $sign ); 
}

#------------------------------------------------------------------------------
#------------------------------------------------------------------------------
sub julian {
  my($jj,$h,$m) = @_;
  my $tmp = (($h * 60) + $m ) / 1440;
  return( $jj + $tmp ); 
}

#------------------------------------------------------------------------------
# Debut du programme principal
#------------------------------------------------------------------------------
#&Date_Init( "TZ=UTC" );
&Date_Init("Language=French", "DateFormat=non-US", "TZ=UTC");
#print STDERR "$#ARGV\n";exit;
#&usage if( $#ARGV == -1);
&get_options;

# ouverture des fichiers resultants, on sort si erreur
open( TSG_FILE, $tsgFile )  or die "Can't open file : $tsgFile\n";
open( ANA_FILE, $anaFile ) or die ("\n" . $anaFile . ": " . $!);
open( OUT_FILE, "+> $outFile" ) or die ("\n" . $outFile . ": " . $!);

# ecriture des entetes
print OUT_FILE "$cycle_mesure  $ship\n";
print OUT_FILE "St  Heure   Date    Latitude   Longitude  Temp_XBT  Temp_TSG  Sal_ANA  Sal_TSG\n\n";
#print HDR_FILE_DEC "$cycle_mesure  $ship\n";
#print HDR_FILE_DEC "St  Anne Jour_julien   Latitude   Longitude  TempCTD  TempTSG  SalCTD  SalTSG\n\n";

# parcourt le fichier ANALYSE
print STDERR  "Lit: $anaFile\n" if defined $ECHO;
# parcourt le fichier TSG
print STDERR  "Lit: $tsgFile\n" if defined $ECHO;

# on lit le fichier 
while( <ANA_FILE> ){           
  # init data to bad values    
  $Temp_XBT = $ANA_PSAL = 0;
  # decode analyse file
  ($sample,$heure,$date,$latitude, $lat_hemi,$longitude,$long_hemi,$Temp_XBT,undef,$ANA_PSAL,undef) = split " ";
  $date = $heure . ':00' .  ' ' . $date;	
  #printf STDERR "$date\n";
  $time=&ParseDate($date);
  #printf STDERR "%s\n", &UnixDate($time,"%H:%M:%S %d/%m/%Y");
  # transforme le day_of_year en julian day
  #$julien = &UnixDate($time,"%j") -1;
  #$julien = &julian( $julien, &UnixDate($time,"%H"),&UnixDate($time,"%M") );
  #$year   = &UnixDate($time,"%Y");	
  $h_date = &UnixDate($time,"%H:%M %d/%m/%Y");
  # 
  #($lat_deg, $lat_min, $lat_hemi) = split " ", $latitude;
  #$lat_dec = &position($lat_deg, $lat_min, $lat_hemi);
  #($long_deg, $long_min, $long_hemi) = split " ", $longitude;
  #$long_dec = &position($long_deg, $long_min, $long_hemi);

  while( <TSG_FILE> ) {
    (undef,$dateTSG,$heureTSG,undef,undef,undef,undef,$SSJT,$SSPS,undef,$SSTP) = split;
    $dateTSG = &ParseDate($heureTSG . ' ' . $dateTSG);
    #printf STDERR "%s\n", &UnixDate($dateTSG, "%H:%M:%S %d/%m/%Y");
    #printf STDERR "%s %s\n", &UnixDate($dateTSG,"%d/%m/%Y %H:%M:%S"), 
    #                         &UnixDate($date,"%d/%m/%Y %H:%M:%S");
    $flag = &Date_Cmp($dateTSG, $time);
    if ($flag == 0) {
            #print "\n$_\n";
      last;  # last is like break in C
    } elsif ($flag > 0) { 
            #print "\n$_\n";
      last;
    } else { 
      $SSJT = $SSPS = $SSTP = 0;
    }
  }
  #&Date_Init("DateFormat=US", "TZ=UTC");
  # affiche l'entete analyse a l'ecran	 
  printf STDERR "   %03d %s %s %s %s %s  %6.3f  %6.3f  %6.3f  %6.3f\n", 
  $sample, $h_date, $latitude, $lat_hemi, $longitude, $long_hemi, 
  $Temp_XBT, $SSTP, $ANA_PSAL, $SSPS if defined $ECHO;

  #printf OUT_FILE "   %03d %s %02d%05.2f %s %03d%05.2f %s  %6.3f  %6.3f  %6.3f  %6.3f\n", $sample, $h_date, $lat_deg, $lat_min, $lat_hemi, $long_deg, $long_min, 
  printf OUT_FILE "   %03d %s %s %s %s %s  %6.3f  %6.3f  %6.3f  %6.3f\n",  
  $sample, $h_date, $latitude, $lat_hemi, $longitude, $long_hemi, 
  $Temp_XBT, $SSTP, $ANA_PSAL, $SSPS;

  #printf HDR_FILE_DEC  "%03d %4d %10.9g %+08.4f %+09.4f %6.3f  %6.3f  %6.3f  %6.3f\n",
  #$station, $year,$julien,$lat_dec,$long_dec, $TempCTD, $TempTSG, $SalCTD, $SalTSG ;
}

# return result for matlab

close TSG_FILE;
close ANA_FILE;
close OUT_FILE;

