#!/usr/bin/perl
#
use Date::Manip;
use Getopt::Long;
use File::Basename;

#------------------------------------------------------------------------------
# Les variables globales
#------------------------------------------------------------------------------
my $offset = 0;
my ($in_file, $out_file);
my $err;

#------------------------------------------------------------------------------
# usage()
#------------------------------------------------------------------------------	
sub usage() {
  print STDERR "\nusage: adjust-ladcp.pl --offset=<value> --file=<file>\n\n";
  exit 1;
}

#------------------------------------------------------------------------------
# get_options()
# analyse les options
#------------------------------------------------------------------------------	
sub get_options() {
  
  &GetOptions ("offset=i"  => \$offset, 
               "file=s"    => \$in_file,
               "help"      => \$help) or &usage;  

  &usage if $help;
}

#------------------------------------------------------------------------------
# Debut du programme principal
#------------------------------------------------------------------------------
&Date_Init( "TZ=UTC" );
&usage if( $#ARGV == -1);
&get_options;

# split in_file and construct out_file
my($name,$path,$suffix) = fileparse $in_file;
$out_file = $name . ".out" . $suffix;

printf( "in_file: %s  out_file: %s  offset: %d\n", $in_file, $out_file, $offset);

# open file descriptor
open( IN_FILE,  $in_file )  or die "Can't open file : $in_file\n";
open( OUT_FILE, "+> $out_file" ) or die "Can't open file : $out_file\n";

$offset = sprintf " %+d seconds", $offset;
printf STDERR "offset: %s\n", $offset;

#read each line
while( <IN_FILE> ){
  # extract data from read line
  my ($year,$month,$day,$hour,$min,$sec,$hundred) = split(/,/);
  my $string = sprintf "%02d/%02d/%02d %02d:%02d:%02d", $month,$day,$year,$hour,$min,$sec;

  my $date = &ParseDate( $string ); 

  #printf STDERR "%s => %s\n", $string, &UnixDate( $date,"%d/%m/%Y %H:%M:%S" );
  
  $date = &DateCalc($date, $offset, \$err);
  printf OUT_FILE "%s,%d\r\n", &UnixDate($date,"%y,%m,%d,%H,%M,%S"), $hundred;

}  

printf( "%d lines modified. OK\nDone ...\n", $. );

close IN_FILE;
close OUT_FILE;
